@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.503";
+our $VERSION = "0.504";
 
 1;
 
@@ -552,9 +552,13 @@ Calls the L<ioctl|SPVM::Sys::Ioctl/"ioctl"> method in the L<Sys::Ioctl|SPVM::Sys
 
 =head2 select
 
-C<static method select : int ($readfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $writefds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $exceptfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $timeout : double);>
+C<static method select : int ($readfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $writefds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $exceptfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $timeout : double = 0);>
 
-Calls the L<select|SPVM::Sys::Select/"select"> method in the L<Sys::Select|SPVM::Sys::Select> class with $ndfs set to 1024.
+Calls the L<select|SPVM::Sys::Select/"select"> method in the Sys::Select class and returns its return value.
+
+If $timeout is greter than or equal to 0, it is converted to a L<Sys::Time::Timeval|SPVM::Sys::Time::Timeval> object. Otherwise it becomes undef.
+
+$nfds is set to 1024.
 
 =head2 bind
 
@@ -1069,6 +1073,8 @@ If the system supports C<FD_CLOEXEC>, this flag is set to $read_fd_ref and $writ
 
 =item * L<Sys::Time::Tms|SPVM::Sys::Time::Tms>
 
+=item * L<Sys::Time::Util|SPVM::Sys::Time::Util>
+
 =item * L<Sys::User|SPVM::Sys::User>
 
 =item * L<Sys::User::Group|SPVM::Sys::User::Group>
